@@ -1480,7 +1480,9 @@ class LinUCB:
         Parameter to control the upper confidence bound (more is higher).
     lambda_ : float > 0
         Regularization parameter. References assumed this would always be equal to 1, but this
-        implementation allows to change it,
+        implementation allows to change it.
+    fit_intercept : bool
+        Whether to add an intercept term to the coefficients.
     njobs : int or None
         Number of parallel jobs to run. If passing None will set it to 1. If passing -1 will
         set it to the number of CPU cores. Be aware that the algorithm will use BLAS function calls,
@@ -1494,11 +1496,11 @@ class LinUCB:
     .. [2] Li, Lihong, et al. "A contextual-bandit approach to personalized news article recommendation."
            Proceedings of the 19th international conference on World wide web. ACM, 2010.
     """
-    def __init__(self, nchoices, alpha = 1.0, lambda_ = 1.0, njobs = 1):
+    def __init__(self, nchoices, alpha = 1.0, lambda_ = 1.0, fit_intercept=True, njobs = 1):
         self._ts = False
-        self._add_common_lin(alpha, lambda_, nchoices, njobs)
+        self._add_common_lin(alpha, lambda_, fit_intercept, nchoices, njobs)
 
-    def _add_common_lin(self, alpha, lambda_, nchoices, njobs):
+    def _add_common_lin(self, alpha, lambda_, fit_intercept, nchoices, njobs):
         if isinstance(alpha, int):
             alpha = float(alpha)
         assert isinstance(alpha, float)
@@ -1511,8 +1513,9 @@ class LinUCB:
         self.njobs = _check_njobs(njobs)
         self.alpha = alpha
         self.lambda_ = lambda_
+        self.fit_intercept = bool(fit_intercept)
         self.nchoices = nchoices
-        self._oracles = [_LinUCBnTSSingle(self.alpha, self.lambda_, self._ts) for n in range(nchoices)]
+        self._oracles = [_LinUCBnTSSingle(self.alpha, self.lambda_, self.fit_intercept, self._ts) for n in range(nchoices)]
         if not self._ts:
             self.v_sq = self.alpha
             del self.alpha
@@ -1706,6 +1709,8 @@ class LinTS(LinUCB):
     lambda_ : float > 0
         Regularization parameter. References assumed this would always be equal to 1, but this
         implementation allows to change it,
+    fit_intercept : bool
+        Whether to add an intercept term to the coefficients.
     njobs : int or None
         Number of parallel jobs to run. If passing None will set it to 1. If passing -1 will
         set it to the number of CPU cores. Be aware that the algorithm will use BLAS function calls,
@@ -1717,9 +1722,9 @@ class LinTS(LinUCB):
     .. [1] Agrawal, Shipra, and Navin Goyal. "Thompson sampling for contextual bandits with linear payoffs."
            International Conference on Machine Learning. 2013.
     """
-    def __init__(self, nchoices, v_sq=1.0, lambda_=1.0, njobs=1):
+    def __init__(self, nchoices, v_sq=1.0, lambda_=1.0, fit_intercept=True, njobs=1):
         self._ts = True
-        self._add_common_lin(v_sq, lambda_, nchoices, njobs)
+        self._add_common_lin(v_sq, lambda_, fit_intercept, nchoices, njobs)
 
 class BayesianUCB(_BasePolicyWithExploit):
     """
